IntoTuple2

Trait IntoTuple2 

pub trait IntoTuple2<T> {
    // Required method
    fn into_tuple2(self) -> (T, T);
}
To manipulate many Point libraries in the same way, we use tuple as a entry point of API. If you implement IntoTuple2 to your point type, you can use it as Point in this library.

Example

use rect_iter::IntoTuple2;
struct Point {
    x: f64,
    y: f64,
}
impl IntoTuple2<f64> for Point {
    fn into_tuple2(self) -> (f64, f64) {
        (self.x, self.y)
    }
}

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: Clone, U> IntoTuple2<T> for Point2D<T, U>

Available on crate feature euclid only.
Source

impl<T: Clone, U> IntoTuple2<T> for Vector2D<T, U>

Available on crate feature euclid only.
Source

impl<T> IntoTuple2<T> for (T, T)

Implementors